function [beta,ConfBeta,theFittedCurve,the80pct,theResiduals] = fitOneBVCEAHist(funcForm,theData,theLegend,theMarker,skipResidualPlots,theCell)


theFontSize = 24;

len = length(theData(:,2));
ytvalues = 1:len;
yvalues = ytvalues./len;
xValuesInArea = theData(:,2);

% x is the x values.  THIS FUNCTION TAKES THE LOG BASE E of this BEFORE FITTING
% theHist is the data values.  ASSUMED TO GO FROM 0 to 1.
%       convert all the x values to fraction of the letterbox area%
MAX_AREA = 512*512;
letterboxMAXAREA = MAX_AREA*0.75;
xValuesInArea = xValuesInArea./letterboxMAXAREA;

%
%       what happens if we ignore everything above 0.5??
% xValuesInArea = xValuesInArea(find(xValuesInArea<0.5));
% len = length(xValuesInArea);
% ytvalues = 1:len;
% yvalues = ytvalues./len;


%       take log of xx values
logOfX = log(xValuesInArea)';  %transpose to get in right form for nlinfit
%

%setup the initial guesses for a and b (in beta(1) and beta(2)
%just use the 1/2 way point for a and 1/10th of that for b
initialBeta(1) = logOfX(round(length(logOfX)/2));
initialBeta(2) = abs(0.1*initialBeta(1));
%   funcForm=1 , use logistic.  funcForm=2, use modified Logistic
%
if (funcForm==1)
    theFunction=@logistic;
    theAntiFunction=@antilogistic;
else
    theFunction=@logisticModified;
    theAntiFunction=@antilogisticModified;
    initialBeta(3) = 0.01;
end;
my_opts = statset('MaxIter',500);
[beta,theResiduals,J] = nlinfit(logOfX,yvalues,theFunction,initialBeta,my_opts);
%produce the fitted curve
theFittedCurve = theFunction(beta,logOfX);
ConfBeta = nlparci(beta,theResiduals,J);
the80pct = theAntiFunction(beta,0.8);
the50pct = theAntiFunction(beta,0.5);
%create the 2 points that will generate the vertical line at the 80% mark
xp = [the50pct the50pct];
yp = [0 1];

confIntervals = num2str(ConfBeta);
str80pct = num2str( exp(the80pct), '%-5.3f');
str50pct = num2str( 100*exp(the50pct), '%-5.1f');
aInterval = ['a(95%): ' confIntervals(1,:)];
bInterval = ['b(95%): ' confIntervals(2,:)];
lbl80pct = ['80% : ' str80pct];
lbl50pct = ['a: ' str50pct ' %'];


celltxt(1) = {aInterval};
celltxt(2) = {bInterval};


if(~skipResidualPlots)
      
    %   figure out the tick labels.  
     wantedXvalues = [1/128,1/64, 1/32, 1/16, 1/8, 1/4, 1/2];
%     wantedXvalues = wantedXvalues*NCELLSFORAREA*2;
     wantedXvalues = log(wantedXvalues);
     xticks = wantedXvalues;
     xlabs = {'';'';'1/32';'1/16';'1/8';'1/4';'1/2'};
   hold on;

   [AX,H1,H2] = plotyy(xp,yp,logOfX,theResiduals);
    hold on;
    set(H1,'LineWidth',2);
    set(H2,'LineWidth',2);
    hold on;
    axes(AX(1));        %left hand axis
    %set(gca,'ColorOrder',colorMat);
     set(gca,'XTick',xticks);
     set(gca,'XTickLabel',xlabs,'FontSize',theFontSize);   %this also alters the legend font size (I think)
    xlabel('Fraction Of Movie Scene Area','FontSize',theFontSize);
    ylabel('Cumulative Proportion of Frames','FontSize',theFontSize);
    ylim([0 1]);
    xlim( [ -5 0]);
     yticks = [0 0.2 0.4 0.6 0.8 1];
     ylabs = {'0'; '0.2'; '0.4';'0.6';'0.8'; '1'};
     set(gca,'YTick',yticks);
     set(gca,'YTickLabel',ylabs,'FontSize', theFontSize);
%     
    plot(logOfX,theFittedCurve,'-k','LineWidth',1);
    hold on;
    plot(logOfX,yvalues,'LineStyle','none','Marker',theMarker,'MarkerSize',4,'MarkerEdgeColor','k');
    hold on;
    if (mod(theCell,2)==0)   %turn off the left hand ticks and labels for even cells 
        %set(gca,'Visible','off');
     ylabel('');
     ylabs = {''};
     set(gca,'YTickLabel',ylabs);
    end;
    if ( theCell<5 )  %turn off x axis label for all except last 2 plots
        xlabel('');
        set(gca,'XTickLabel','');
    end;
    if( theCell==1 || theCell==5)  %turn off Y axis text label for upper and lower
        ylabel('');
    end;
    
    
    
    %axis_handle = get(AX(2));
    %set(axis_handle,'YLim',[-0.1 +0.1]);
    axes(AX(2));  %set current axis to the right hand one
    ylabel('Data-Fit','FontSize',theFontSize);
    ylim([-0.1 +0.1]);
    xlim( [-5.0 0]);
    yticks = -0.1:0.05:0.1;
    ylabs = {'-.1'; '-.05'; '0';'.05';'.1'};
   % set(gca,'ColorOrder',colorMat);
    set(gca,'YTick',yticks);
    set(gca,'YTickLabel',ylabs,'FontSize', theFontSize,'FontWeight', 'bold');
    %set(gca,'XAxisLocation','top');
    set(gca,'XTick',[]);  %no X ticks
    set(gca,'XtickLabel','');  %no x tick labels
    %set(gca,'Visible','off');  %turn off the top axis
    %set(gca,'YLim',[-0.1 +0.1]); 
    %legend(theLegend,4);
    
    %  uncomment this lines to put the parameter values with confidence limits
    %  on the plots
    %text(.5,0.065,celltxt,'FontSize',18);
    %text(-4.5,0.065,lbl80pct,'FontSize',theFontSize);
    text(-4.5,0.065,lbl50pct,'FontSize',theFontSize);
    if (mod(theCell,2)==1)   %turn off the right hand axis for odd cells 
        set(gca,'Visible','off');
    end;
    text(wantedXvalues(6),-0.08,theLegend,'FontSize', theFontSize);

end;


return;